@@ -1,11 +1,8 @@
 package internal
 
 import (
-	"crypto/md5"
-	"encoding/hex"
 	"errors"
 	"fmt"
-	"io"
 	"log/slog"
 	"os"
 	"path/filepath"
@@ -15,13 +12,10 @@ import (
 	"sort"
 	"strconv"
 	"strings"
-	"time"
 
 	"github.com/yorukot/superfile/src/internal/utils"
 
 	"github.com/yorukot/superfile/src/internal/common"
-
-	"github.com/lithammer/shortuuid"
 )
 
 // Check if the directory is external disk path
@@ -310,163 +304,12 @@ func renameIfDuplicate(destination string) (string, error) {
 	}
 }
 
-// TODO : Move this model related function to the right file. Should not be in functions file.
-func (m *model) returnMetaData() {
-	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
-	cursor := panel.cursor
-	id := shortuuid.New()
-
-	message := channelMessage{
-		messageID:   id,
-		messageType: sendMetadata,
-		metadata:    m.fileMetaData.metaData,
-	}
-
-	// Obtaining metadata will take time. If metadata is obtained for every passing file, it will cause lag.
-	// Therefore, it is necessary to detect whether it is just browsing or stopping on that file or directory.
-	LastTimeCursorMove = [2]int{int(time.Now().UnixMicro()), cursor}
-	time.Sleep(150 * time.Millisecond)
-
-	if LastTimeCursorMove[1] != cursor && m.focusPanel != metadataFocus {
-		return
-	}
-
-	m.fileMetaData.metaData = m.fileMetaData.metaData[:0]
-	if len(panel.element) == 0 {
-		message.metadata = m.fileMetaData.metaData
-		channel <- message
-		return
-	}
-	if len(panel.element[panel.cursor].metaData) != 0 && m.focusPanel != metadataFocus {
-		m.fileMetaData.metaData = panel.element[panel.cursor].metaData
-		message.metadata = m.fileMetaData.metaData
-		channel <- message
-		return
-	}
-	filePath := panel.element[panel.cursor].location
-
-	fileInfo, err := os.Stat(filePath)
-
-	if isSymlink(filePath) {
-		_, symlinkErr := filepath.EvalSymlinks(filePath)
-		if symlinkErr != nil {
-			m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"Link file is broken!", ""})
-		} else {
-			m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"This is a link file.", ""})
-		}
-		message.metadata = m.fileMetaData.metaData
-		channel <- message
-		return
-	}
-
-	if err != nil {
-		slog.Error("Error while return meta data function get file state", "error", err)
-	}
-
-	if fileInfo.IsDir() {
-		m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"Name", fileInfo.Name()})
-		if m.focusPanel == metadataFocus {
-			// TODO : Calling dirSize() could be expensive for large directories, as it recursively
-			// walks the entire tree. Consider lazy loading, caching, or an async approach to avoid UI lockups.
-			m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"Size", common.FormatFileSize(dirSize(filePath))})
-		}
-		m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"Date Modified", fileInfo.ModTime().String()})
-		m.fileMetaData.metaData = append(m.fileMetaData.metaData, [2]string{"Permissions", fileInfo.Mode().String()})
-		message.metadata = m.fileMetaData.metaData
-		channel <- message
-		return
-	}
-
-	checkIsSymlinked, err := os.Lstat(filePath)
-	if err != nil {
-		slog.Error("Error when getting file info", "error", err)
-		return
-	}
-
-	if common.Config.Metadata && checkIsSymlinked.Mode()&os.ModeSymlink == 0 && et != nil {
-		fileInfos := et.ExtractMetadata(filePath)
-
-		for _, fileInfo := range fileInfos {
-			if fileInfo.Err != nil {
-				slog.Error("Error while return metadata function", "fileInfo", fileInfo, "error", fileInfo.Err)
-				continue
-			}
-
-			for k, v := range fileInfo.Fields {
-				temp := [2]string{k, fmt.Sprintf("%v", v)}
-				m.fileMetaData.metaData = append(m.fileMetaData.metaData, temp)
-			}
-		}
-	} else {
-		fileName := [2]string{"Name", fileInfo.Name()}
-		fileSize := [2]string{"Size", common.FormatFileSize(fileInfo.Size())}
-		fileModifyData := [2]string{"Date Modified", fileInfo.ModTime().String()}
-		filePermissions := [2]string{"Permissions", fileInfo.Mode().String()}
-
-		if common.Config.EnableMD5Checksum {
-			// Calculate MD5 checksum
-			checksum, err := calculateMD5Checksum(filePath)
-			if err != nil {
-				slog.Error("Error calculating MD5 checksum", "error", err)
-			} else {
-				md5Data := [2]string{"MD5Checksum", checksum}
-				m.fileMetaData.metaData = append(m.fileMetaData.metaData, md5Data)
-			}
-		}
-
-		m.fileMetaData.metaData = append(m.fileMetaData.metaData, fileName, fileSize, fileModifyData, filePermissions)
-	}
-
-	message.metadata = m.fileMetaData.metaData
-	channel <- message
-
-	panel.element[panel.cursor].metaData = m.fileMetaData.metaData
-}
-
 // TODO : Replace all usage of "m.fileModel.filePanels[m.filePanelFocusIndex]" with this
 // There are many usage
 func (m *model) getFocusedFilePanel() *filePanel {
 	return &m.fileModel.filePanels[m.filePanelFocusIndex]
 }
 
-func calculateMD5Checksum(filePath string) (string, error) {
-	file, err := os.Open(filePath)
-	if err != nil {
-		return "", fmt.Errorf("failed to open file: %w", err)
-	}
-	defer file.Close()
-
-	hash := md5.New()
-	if _, err := io.Copy(hash, file); err != nil {
-		return "", fmt.Errorf("failed to calculate MD5 checksum: %w", err)
-	}
-
-	checksum := hex.EncodeToString(hash.Sum(nil))
-	return checksum, nil
-}
-
-// Get directory total size
-func dirSize(path string) int64 {
-	var size int64
-	// Its named walkErr to prevent shadowing
-	walkErr := filepath.WalkDir(path, func(_ string, entry os.DirEntry, err error) error {
-		if err != nil {
-			slog.Error("Dir size function error", "error", err)
-		}
-		if !entry.IsDir() {
-			info, infoErr := entry.Info()
-			if infoErr == nil {
-				size += info.Size()
-			}
-		}
-		return err
-	})
-	if walkErr != nil {
-		slog.Error("errors during WalkDir", "error", walkErr)
-	}
-	return size
-}
-
 // Count how many file in the directory
 func countFiles(dirPath string) (int, error) {
 	count := 0
@@ -484,15 +327,6 @@ func countFiles(dirPath string) (int, error) {
 	return count, err
 }
 
-// Check whether is symlinks
-func isSymlink(filePath string) bool {
-	fileInfo, err := os.Lstat(filePath)
-	if err != nil {
-		return true
-	}
-	return fileInfo.Mode()&os.ModeSymlink != 0
-}
-
 func isImageFile(filename string) bool {
 	imageExtensions := map[string]bool{
 		".jpg":  true,
