@@ -23,13 +23,9 @@ func (m *model) mainKey(msg string) tea.Cmd {
 		case processBarFocus:
 			m.processBarModel.listUp(m.footerHeight)
 		case metadataFocus:
-			m.fileMetaData.listUp()
+			m.fileMetaData.ListUp()
 		case nonePanelFocus:
 			m.fileModel.filePanels[m.filePanelFocusIndex].listUp(m.mainPanelHeight)
-			m.fileMetaData.renderIndex = 0
-			go func() {
-				m.returnMetaData()
-			}()
 		}
 
 		// If move down Key is pressed, check the current state and executes
@@ -40,13 +36,9 @@ func (m *model) mainKey(msg string) tea.Cmd {
 		case processBarFocus:
 			m.processBarModel.listDown(m.footerHeight)
 		case metadataFocus:
-			m.fileMetaData.listDown()
+			m.fileMetaData.ListDown()
 		case nonePanelFocus:
 			m.fileModel.filePanels[m.filePanelFocusIndex].listDown(m.mainPanelHeight)
-			m.fileMetaData.renderIndex = 0
-			go func() {
-				m.returnMetaData()
-			}()
 		}
 
 	case slices.Contains(common.Hotkeys.PageUp, msg):
@@ -83,9 +75,6 @@ func (m *model) mainKey(msg string) tea.Cmd {
 
 	case slices.Contains(common.Hotkeys.FocusOnMetaData, msg):
 		m.focusOnMetadata()
-		go func() {
-			m.returnMetaData()
-		}()
 
 	case slices.Contains(common.Hotkeys.PasteItems, msg):
 		go func() {
