@@ -11,7 +11,9 @@ import (
 	"strings"
 	"time"
 
+	"github.com/yorukot/superfile/src/config/icon"
 	"github.com/yorukot/superfile/src/internal/common"
+	"github.com/yorukot/superfile/src/internal/ui/metadata"
 	"github.com/yorukot/superfile/src/internal/utils"
 
 	"github.com/barasher/go-exiftool"
@@ -81,6 +83,10 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		}
 	case tea.KeyMsg:
 		cmd = tea.Batch(cmd, m.handleKeyInput(msg))
+	case MetadataMsg:
+		// Update the metadata and return
+		m.handleMetadataMsg(msg)
+		return m, cmd
 	default:
 		slog.Debug("Message of type that is not handled", "type", reflect.TypeOf(msg))
 	}
@@ -89,15 +95,86 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	m.sidebarModel.UpdateDirectories()
 
 	// check if there already have listening message
+	// TODO: Fix this. This is wrong, and it will cause unnecessary goroutines spawned continuously
+	// for every Update() , stuck listening for channel message
+	// We could move to only issuing listen commands on receiving channel messages.
+	// Have the channel as a part of model struct, and remove ListeningMessage variable altogether.
+	// See - Issue #946
+	var listenChannelCommand tea.Cmd
 	if !ListeningMessage {
-		cmd = tea.Batch(cmd, listenForChannelMessage(channel))
+		listenChannelCommand = listenForChannelMessage(channel)
 	}
 
 	m.getFilePanelItems()
+
+	metadataCmd := m.getMetadataCmd()
+
+	// TODO: Move to utility
+	if m.focusPanel != metadataFocus {
+		m.fileMetaData.ResetRender()
+	}
+
+	// TODO: Entirely remove the need of this variable, and handle first loading via Init()
+	// Init() should return a basic model object with all IO waiting via a tea.Cmd
 	if !m.firstLoadingComplete {
 		m.firstLoadingComplete = true
 	}
-	return m, tea.Batch(cmd)
+	return m, tea.Batch(cmd, listenChannelCommand, metadataCmd)
+}
+
+func (m *model) handleMetadataMsg(msg MetadataMsg) {
+	slog.Debug("Got metadata message", "id", msg.reqID)
+
+	selectedItem := m.getFocusedFilePanel().getSelectedItemPtr()
+	if selectedItem == nil {
+		slog.Debug("Panel empty or cursor invalid. Ignoring MetadataMsg")
+		return
+	}
+	if selectedItem.location != msg.metadata.GetPath() {
+		slog.Debug("MetadataMsg for older files. Ignoring")
+		return
+	}
+	m.fileMetaData.SetMetadata(msg.metadata)
+	selectedItem.metaData = msg.metadata.GetData()
+}
+
+// Note : Maybe we should not trigger metadata fetch for updates
+// that dont change the currently selected file panel element
+// TODO : At least dont trigger metadata fetch when user is scrolling
+// through the metadata panel
+func (m *model) getMetadataCmd() tea.Cmd {
+	if len(m.getFocusedFilePanel().element) == 0 {
+		m.fileMetaData.SetBlank()
+		return nil
+	}
+	selectedItem := m.getFocusedFilePanel().getSelectedItem()
+
+	// Note : This will cause metadata not being refreshed when you are not scrolling,
+	// or filepanel is not getting updated. Its not a big problem as we repeatedly refresh filepanel
+	// In case this is a significant issue, we would implement metadata caching.
+	// But need to implement it carefully if we do. Make sure cache is not unbounded
+	// Remove metadata from filepanel.elemets[] and have cache as source of truth.
+	// Have a TTL for expiry, or lister for file update events.
+	if len(selectedItem.metaData) > 0 {
+		m.fileMetaData.SetMetadata(metadata.NewMetadata(selectedItem.metaData,
+			selectedItem.location, ""))
+		return nil
+	}
+	if m.fileMetaData.IsBlank() {
+		m.fileMetaData.SetInfoMsg(icon.InOperation + icon.Space + "Loading metadata...")
+	}
+	metadataFocussed := m.focusPanel == metadataFocus
+	reqCnt := m.metadataRequestCnt
+	m.metadataRequestCnt++
+	// If there are too many metadata fetches, we need to have a cache with path as a key
+	// and timeout based eviction
+	slog.Debug("Submitting metadata fetch request", "id", reqCnt, "path", selectedItem.location)
+	return func() tea.Msg {
+		return MetadataMsg{
+			metadata: metadata.GetMetadata(selectedItem.location, metadataFocussed, et),
+			reqID:    reqCnt,
+		}
+	}
 }
 
 // Handle message exchanging within the application
@@ -107,8 +184,6 @@ func (m *model) handleChannelMessage(msg channelMessage) {
 		m.warnModal = msg.warnModal
 	case sendNotifyModal:
 		m.notifyModal = msg.notifyModal
-	case sendMetadata:
-		m.fileMetaData.metaData = msg.metadata
 	case sendProcess:
 		if !arrayContains(m.processBarModel.processList, msg.messageID) {
 			m.processBarModel.processList = append(m.processBarModel.processList, msg.messageID)
@@ -137,6 +212,7 @@ func (m *model) handleWindowResize(msg tea.WindowSizeMsg) {
 	m.setFilePanelsSize(msg.Width)
 	m.setHeightValues(msg.Height)
 	m.setHelpMenuSize()
+	m.setMetadataModelSize()
 	m.setPromptModelSize()
 
 	if m.fileModel.maxFilePanel >= 10 {
@@ -207,6 +283,10 @@ func (m *model) setPromptModelSize() {
 	m.promptModal.SetWidth(m.fullWidth / 2)
 }
 
+func (m *model) setMetadataModelSize() {
+	m.fileMetaData.SetDimensions(utils.FooterWidth(m.fullWidth)+2, m.footerHeight+2)
+}
+
 // Identify the current state of the application m and properly handle the
 // msg keybind pressed
 func (m *model) handleKeyInput(msg tea.KeyMsg) tea.Cmd {
@@ -433,7 +513,7 @@ func (m model) View() string {
 	if m.toggleFooter {
 		processBar := m.processBarRender()
 
-		metaData := m.metadataRender()
+		metaData := m.fileMetaData.Render(m.focusPanel == metadataFocus)
 
 		clipboardBar := m.clipboardRender()
 
