@@ -296,117 +296,6 @@ func (m *model) processBarRender() string {
 	return r.Render()
 }
 
-// This updates m.fileMetaData
-func (m *model) metadataRender() string {
-	m.ensureMetadataLoaded()
-
-	// TODO : This is bad, this is bad mixing rendering of content and loading of content.
-	// The metadata should be filled in slice correctly at the time its loaded, not when we
-	// are rendering it.
-	sortMetadata(m.fileMetaData.metaData)
-	maxKeyLen := getMaxKeyLength(m.fileMetaData.metaData)
-	sprintfLen, valLen := computeMetadataWidths(m.fullWidth, maxKeyLen)
-
-	r := ui.MetadataRenderer(m.footerHeight+2, utils.FooterWidth(m.fullWidth)+2, m.focusPanel == metadataFocus)
-	if len(m.fileMetaData.metaData) > 0 {
-		r.SetBorderInfoItems(fmt.Sprintf("%d/%d", m.fileMetaData.renderIndex+1, len(m.fileMetaData.metaData)))
-	}
-
-	lines := formatMetadataLines(m.fileMetaData.metaData, m.fileMetaData.renderIndex, m.footerHeight, sprintfLen, valLen)
-	r.AddLines(lines...)
-
-	return r.Render()
-}
-
-func (m *model) ensureMetadataLoaded() {
-	if len(m.fileMetaData.metaData) == 0 &&
-		len(m.fileModel.filePanels[m.filePanelFocusIndex].element) > 0 &&
-		!m.fileModel.renaming {
-		m.fileMetaData.metaData = [][2]string{
-			{"", ""},
-			{" " + icon.InOperation + "  Loading metadata...", ""},
-		}
-		// TODO : This needs to be improved, we are updating m.fileMetaData is a separate goroutine
-		// while also modifying it here in the function. It could cause issues.
-		go func() {
-			m.returnMetaData()
-		}()
-	}
-}
-
-// TODO : Move this and many other utility function to separate files
-// and unit test them too.
-func sortMetadata(meta [][2]string) {
-	priority := map[string]int{
-		"Name":          0,
-		"Size":          1,
-		"Date Modified": 2,
-		"Date Accessed": 3,
-	}
-
-	sort.SliceStable(meta, func(i, j int) bool {
-		pi, iOkay := priority[meta[i][0]]
-		pj, jOkay := priority[meta[j][0]]
-
-		// Both are priority fields
-		if iOkay && jOkay {
-			return pi < pj
-		}
-		// i is a priority field, and j is not
-		if iOkay {
-			return true
-		}
-
-		// j is a priority field, and i is not
-		if jOkay {
-			return false
-		}
-
-		// None of them are priority fields, sort with name
-		return meta[i][0] < meta[j][0]
-	})
-}
-
-func getMaxKeyLength(meta [][2]string) int {
-	maxLen := 0
-	for _, pair := range meta {
-		if len(pair[0]) > maxLen {
-			maxLen = len(pair[0])
-		}
-	}
-	return maxLen
-}
-
-func computeMetadataWidths(fullWidth, maxKeyLen int) (int, int) {
-	metadataPanelWidth := utils.FooterWidth(fullWidth)
-
-	// Value Length = PanelLength - Key length - 2 (for border)
-	valueLen := metadataPanelWidth - maxKeyLen - 2
-	sprintfLen := maxKeyLen + 1
-	if valueLen < metadataPanelWidth/2 {
-		valueLen = metadataPanelWidth/2 - 2
-		sprintfLen = valueLen
-	}
-
-	return sprintfLen, valueLen
-}
-
-// TODO : Simplify these mystic calculations, or add explanation comments.
-func formatMetadataLines(meta [][2]string, startIdx, height, sprintfLen, valueLen int) []string {
-	lines := []string{}
-	endIdx := min(startIdx+height, len(meta))
-	for i := startIdx; i < endIdx; i++ {
-		key := meta[i][0]
-		value := common.TruncateMiddleText(meta[i][1], valueLen, "...")
-		if utils.FooterWidth(0)-sprintfLen-3 < utils.FooterWidth(0)/2 {
-			key = common.TruncateMiddleText(key, valueLen, "...")
-		}
-		line := fmt.Sprintf("%-*s %s", sprintfLen, key, value)
-		lines = append(lines, line)
-	}
-	return lines
-}
-
 func (m *model) clipboardRender() string {
 	// render
 	var bottomWidth int
