@@ -155,7 +155,7 @@ func LoadTomlFile(filePath string, defaultData string, target interface{}, fixFl
 		resultErr.UpdateMessageAndError("failed to marshal config to TOML", err)
 		return resultErr
 	}
-	_, err = origFile.Write(tomlData)
+	_, err = origFile.WriteAt(tomlData, 0)
 
 	if err != nil {
 		resultErr.UpdateMessageAndError("failed to write TOML data to original file", err)
@@ -189,3 +189,26 @@ func ResolveAbsPath(currentDir string, path string) string {
 	}
 	return filepath.Clean(path)
 }
+
+// Get directory total size
+// TODO: Uni test this
+func DirSize(path string) int64 {
+	var size int64
+	// Its named walkErr to prevent shadowing
+	walkErr := filepath.WalkDir(path, func(_ string, entry os.DirEntry, err error) error {
+		if err != nil {
+			slog.Error("Dir size function error", "error", err)
+		}
+		if !entry.IsDir() {
+			info, infoErr := entry.Info()
+			if infoErr == nil {
+				size += info.Size()
+			}
+		}
+		return err
+	})
+	if walkErr != nil {
+		slog.Error("errors during WalkDir", "error", walkErr)
+	}
+	return size
+}
