@@ -23,7 +23,7 @@ class CutTest(GenericTestImpl):
             test_dirs=[DIR1, DIR2],
             test_files=[(FILE1, tconst.FILE_TEXT1)],
             key_inputs=[keys.KEY_CTRL_X, keys.KEY_LEFT, keys.KEY_DOWN, 
-                keys.KEY_ENTER, keys.KEY_CTRL_V],
+                keys.KEY_ENTER, keys.KEY_PASTE],
             validate_exists=[FILE1_CUT1],
             validate_not_exists=[FILE1]
         )
